==> griffv2-2.0.0-py3-none-any.whl: griff/appli/command/command_handler.py <==
from abc import ABC
from typing import TypeVar, Generic, List, Any, Literal

import typing_extensions
from griff.appli.command.command import Command
from griff.appli.event.event import Event
from griff.appli.message.message_handler import (
    MessageHandler,
    MessageResponse,
    MessageErrorResponse,
)
from griff.infra.registry.meta_registry import MetaCommandHandlerRegistry
from pydantic import Field
from pydantic.main import IncEx


class CommandSuccessResponse(MessageResponse, ABC):
    events: List[Event] = Field(default_factory=list)

    def model_dump(
        self,
        *,
        mode: typing_extensions.Literal["json", "python"] | str = "python",
        include: IncEx = None,
        exclude: IncEx = None,
        context: dict[str, Any] | None = None,
        by_alias: bool = False,
        exclude_unset: bool = False,
        exclude_defaults: bool = False,
        exclude_none: bool = False,
        round_trip: bool = False,
        warnings: bool | Literal["none", "warn", "error"] = True,
        serialize_as_any: bool = False
    ) -> dict[str, Any]:
        result = super().model_dump(
            mode=mode,
            include=include,
            exclude=exclude,
            context=context,
            by_alias=by_alias,
            exclude_unset=exclude_unset,
            exclude_defaults=exclude_defaults,
            exclude_none=exclude_none,
            round_trip=round_trip,
            warnings=warnings,
            serialize_as_any=serialize_as_any,
        )
        # pydantic dump model as only Event ignoring specific event fields
        result["events"] = [e.model_dump() for e in self.events]
        return result


class CommandErrorResponse(MessageErrorResponse, ABC):
    ...


CommandResponse = CommandSuccessResponse | CommandErrorResponse

CM = TypeVar("CM", bound=Command)
CR = TypeVar("CR", bound=CommandResponse)


class CommandHandler(
    Generic[CM, CR], MessageHandler[CM, CR], ABC, metaclass=MetaCommandHandlerRegistry
):
    ...

==> griffv2-2.0.8-py3-none-any.whl: griff/appli/command/command_handler.py <==
from abc import ABC, abstractmethod
from typing import TypeVar, Generic, List, Any, Literal

from injector import inject
from pydantic import Field
from pydantic.main import IncEx

from griff.appli.command.command import Command
from griff.appli.event.event import Event
from griff.appli.message.message_handler import (
    MessageHandler,
    MessageErrorResponse,
    MessageSuccessResponse,
    EntityIdContent,
)
from griff.appli.policies.policy import PolicyResult, verify_policies, Policy
from griff.infra.registry.meta_registry import MetaCommandHandlerRegistry


class CommandSuccessResponse(MessageSuccessResponse, ABC):
    events: List[Event] = Field(default_factory=list)

    def model_dump(
        self,
        *,
        mode: Literal["json", "python"] | str = "python",
        include: IncEx | None = None,
        exclude: IncEx | None = None,
        context: Any | None = None,
        by_alias: bool = False,
        exclude_unset: bool = False,
        exclude_defaults: bool = False,
        exclude_none: bool = False,
        round_trip: bool = False,
        warnings: bool | Literal["none", "warn", "error"] = True,
        serialize_as_any: bool = False
    ) -> dict[str, Any]:
        result = super().model_dump(
            mode=mode,
            include=include,
            exclude=exclude,
            context=context,
            by_alias=by_alias,
            exclude_unset=exclude_unset,
            exclude_defaults=exclude_defaults,
            exclude_none=exclude_none,
            round_trip=round_trip,
            warnings=warnings,
            serialize_as_any=serialize_as_any,
        )
        # pydantic dump model as only Event ignoring specific event fields
        result["events"] = [e.model_dump() for e in self.events]
        return result


class CommandErrorResponse(MessageErrorResponse, ABC):
    ...


class CommandEntityIdResponse(CommandSuccessResponse):  # pragma: no cover
    content: EntityIdContent


CommandResponse = CommandSuccessResponse | CommandErrorResponse

CM = TypeVar("CM", bound=Command)
CR = TypeVar("CR", bound=CommandResponse)


class CommandHandler(
    Generic[CM, CR], MessageHandler[CM, CR], ABC, metaclass=MetaCommandHandlerRegistry
):
    @inject
    def __init__(self):
        super().__init__()
        self._policies = []

    @property
    @abstractmethod
    def policies(self) -> List[Policy]:
        return self._policies

    async def verify_policies(self, command: CM) -> PolicyResult:
        return await verify_policies(command, self.policies)
